declare const ruleIdSymbol: unique symbol;
declare type RuleId = {
    __brand: typeof ruleIdSymbol;
};

/**
 * Identifiers with a binary dot operator.
 * Examples: `baz` or `foo.bar`
*/
declare type ScopeName = string;
/**
 * An expression language of ScopePathStr with a binary comma (to indicate alternatives) operator.
 * Examples: `foo.bar boo.baz,quick quack`
*/
declare type ScopePattern = string;
/**
 * A TextMate theme.
 */
interface IRawTheme {
    readonly name?: string;
    readonly settings: IRawThemeSetting[];
}
/**
 * A single theme setting.
 */
interface IRawThemeSetting {
    readonly name?: string;
    readonly scope?: ScopePattern | ScopePattern[];
    readonly settings: {
        readonly fontStyle?: string;
        readonly foreground?: string;
        readonly background?: string;
    };
}

interface IRawGrammar extends ILocatable {
    repository: IRawRepository;
    readonly scopeName: ScopeName;
    readonly patterns: IRawRule[];
    readonly injections?: {
        [expression: string]: IRawRule;
    };
    readonly injectionSelector?: string;
    readonly fileTypes?: string[];
    readonly name?: string;
    readonly firstLineMatch?: string;
}
/**
 * Allowed values:
 * * Scope Name, e.g. `source.ts`
 * * Top level scope reference, e.g. `source.ts#entity.name.class`
 * * Relative scope reference, e.g. `#entity.name.class`
 * * self, e.g. `$self`
 * * base, e.g. `$base`
 */
declare type IncludeString = string;
declare type RegExpString = string;
interface IRawRepositoryMap {
    [name: string]: IRawRule;
    $self: IRawRule;
    $base: IRawRule;
}
declare type IRawRepository = IRawRepositoryMap & ILocatable;
interface IRawRule extends ILocatable {
    id?: RuleId;
    readonly include?: IncludeString;
    readonly name?: ScopeName;
    readonly contentName?: ScopeName;
    readonly match?: RegExpString;
    readonly captures?: IRawCaptures;
    readonly begin?: RegExpString;
    readonly beginCaptures?: IRawCaptures;
    readonly end?: RegExpString;
    readonly endCaptures?: IRawCaptures;
    readonly while?: RegExpString;
    readonly whileCaptures?: IRawCaptures;
    readonly patterns?: IRawRule[];
    readonly repository?: IRawRepository;
    readonly applyEndPatternLast?: boolean;
}
declare type IRawCaptures = IRawCapturesMap & ILocatable;
interface IRawCapturesMap {
    [captureId: string]: IRawRule;
}
interface ILocation {
    readonly filename: string;
    readonly line: number;
    readonly char: number;
}
interface ILocatable {
    readonly $vscodeTextmateLocation?: ILocation;
}

type DynamicLangReg = () => Promise<{
    default: LanguageRegistration;
}>;
declare const bundledLanguagesBase: {
    abap: DynamicLangReg;
    "actionscript-3": DynamicLangReg;
    ada: DynamicLangReg;
    apache: DynamicLangReg;
    apex: DynamicLangReg;
    apl: DynamicLangReg;
    applescript: DynamicLangReg;
    ara: DynamicLangReg;
    asm: DynamicLangReg;
    astro: DynamicLangReg;
    awk: DynamicLangReg;
    ballerina: DynamicLangReg;
    bat: DynamicLangReg;
    beancount: DynamicLangReg;
    berry: DynamicLangReg;
    bibtex: DynamicLangReg;
    bicep: DynamicLangReg;
    blade: DynamicLangReg;
    c: DynamicLangReg;
    cadence: DynamicLangReg;
    clarity: DynamicLangReg;
    clojure: DynamicLangReg;
    cmake: DynamicLangReg;
    cobol: DynamicLangReg;
    codeql: DynamicLangReg;
    coffee: DynamicLangReg;
    cpp: DynamicLangReg;
    crystal: DynamicLangReg;
    csharp: DynamicLangReg;
    css: DynamicLangReg;
    cue: DynamicLangReg;
    cypher: DynamicLangReg;
    d: DynamicLangReg;
    dart: DynamicLangReg;
    dax: DynamicLangReg;
    diff: DynamicLangReg;
    docker: DynamicLangReg;
    "dream-maker": DynamicLangReg;
    elixir: DynamicLangReg;
    elm: DynamicLangReg;
    erb: DynamicLangReg;
    erlang: DynamicLangReg;
    fish: DynamicLangReg;
    fsharp: DynamicLangReg;
    gdresource: DynamicLangReg;
    gdscript: DynamicLangReg;
    gdshader: DynamicLangReg;
    gherkin: DynamicLangReg;
    "git-commit": DynamicLangReg;
    "git-rebase": DynamicLangReg;
    "glimmer-js": DynamicLangReg;
    "glimmer-ts": DynamicLangReg;
    glsl: DynamicLangReg;
    gnuplot: DynamicLangReg;
    go: DynamicLangReg;
    graphql: DynamicLangReg;
    groovy: DynamicLangReg;
    hack: DynamicLangReg;
    haml: DynamicLangReg;
    handlebars: DynamicLangReg;
    haskell: DynamicLangReg;
    hcl: DynamicLangReg;
    hjson: DynamicLangReg;
    hlsl: DynamicLangReg;
    html: DynamicLangReg;
    http: DynamicLangReg;
    imba: DynamicLangReg;
    ini: DynamicLangReg;
    java: DynamicLangReg;
    javascript: DynamicLangReg;
    "jinja-html": DynamicLangReg;
    jison: DynamicLangReg;
    json: DynamicLangReg;
    json5: DynamicLangReg;
    jsonc: DynamicLangReg;
    jsonl: DynamicLangReg;
    jsonnet: DynamicLangReg;
    jssm: DynamicLangReg;
    jsx: DynamicLangReg;
    julia: DynamicLangReg;
    kotlin: DynamicLangReg;
    kusto: DynamicLangReg;
    latex: DynamicLangReg;
    less: DynamicLangReg;
    liquid: DynamicLangReg;
    lisp: DynamicLangReg;
    logo: DynamicLangReg;
    lua: DynamicLangReg;
    make: DynamicLangReg;
    markdown: DynamicLangReg;
    marko: DynamicLangReg;
    matlab: DynamicLangReg;
    mdx: DynamicLangReg;
    mermaid: DynamicLangReg;
    narrat: DynamicLangReg;
    nextflow: DynamicLangReg;
    nginx: DynamicLangReg;
    nim: DynamicLangReg;
    nix: DynamicLangReg;
    "objective-c": DynamicLangReg;
    "objective-cpp": DynamicLangReg;
    ocaml: DynamicLangReg;
    pascal: DynamicLangReg;
    perl: DynamicLangReg;
    php: DynamicLangReg;
    plsql: DynamicLangReg;
    postcss: DynamicLangReg;
    powerquery: DynamicLangReg;
    powershell: DynamicLangReg;
    prisma: DynamicLangReg;
    prolog: DynamicLangReg;
    proto: DynamicLangReg;
    pug: DynamicLangReg;
    puppet: DynamicLangReg;
    purescript: DynamicLangReg;
    python: DynamicLangReg;
    r: DynamicLangReg;
    raku: DynamicLangReg;
    razor: DynamicLangReg;
    reg: DynamicLangReg;
    rel: DynamicLangReg;
    riscv: DynamicLangReg;
    rst: DynamicLangReg;
    ruby: DynamicLangReg;
    rust: DynamicLangReg;
    sas: DynamicLangReg;
    sass: DynamicLangReg;
    scala: DynamicLangReg;
    scheme: DynamicLangReg;
    scss: DynamicLangReg;
    shaderlab: DynamicLangReg;
    shellscript: DynamicLangReg;
    smalltalk: DynamicLangReg;
    solidity: DynamicLangReg;
    sparql: DynamicLangReg;
    sql: DynamicLangReg;
    "ssh-config": DynamicLangReg;
    stata: DynamicLangReg;
    stylus: DynamicLangReg;
    svelte: DynamicLangReg;
    swift: DynamicLangReg;
    "system-verilog": DynamicLangReg;
    tasl: DynamicLangReg;
    tcl: DynamicLangReg;
    tex: DynamicLangReg;
    toml: DynamicLangReg;
    tsx: DynamicLangReg;
    turtle: DynamicLangReg;
    twig: DynamicLangReg;
    typescript: DynamicLangReg;
    v: DynamicLangReg;
    vb: DynamicLangReg;
    verilog: DynamicLangReg;
    vhdl: DynamicLangReg;
    viml: DynamicLangReg;
    "vue-html": DynamicLangReg;
    vue: DynamicLangReg;
    vyper: DynamicLangReg;
    wasm: DynamicLangReg;
    wenyan: DynamicLangReg;
    wgsl: DynamicLangReg;
    wolfram: DynamicLangReg;
    xml: DynamicLangReg;
    xsl: DynamicLangReg;
    yaml: DynamicLangReg;
    zenscript: DynamicLangReg;
};
declare const bundledLanguagesAlias: {
    batch: DynamicLangReg;
    be: DynamicLangReg;
    cdc: DynamicLangReg;
    clj: DynamicLangReg;
    ql: DynamicLangReg;
    "c#": DynamicLangReg;
    cs: DynamicLangReg;
    cql: DynamicLangReg;
    dockerfile: DynamicLangReg;
    erl: DynamicLangReg;
    "f#": DynamicLangReg;
    fs: DynamicLangReg;
    gjs: DynamicLangReg;
    gts: DynamicLangReg;
    hbs: DynamicLangReg;
    hs: DynamicLangReg;
    properties: DynamicLangReg;
    js: DynamicLangReg;
    fsl: DynamicLangReg;
    kql: DynamicLangReg;
    makefile: DynamicLangReg;
    md: DynamicLangReg;
    nar: DynamicLangReg;
    nf: DynamicLangReg;
    objc: DynamicLangReg;
    ps: DynamicLangReg;
    ps1: DynamicLangReg;
    jade: DynamicLangReg;
    py: DynamicLangReg;
    perl6: DynamicLangReg;
    rb: DynamicLangReg;
    rs: DynamicLangReg;
    shader: DynamicLangReg;
    bash: DynamicLangReg;
    console: DynamicLangReg;
    sh: DynamicLangReg;
    shell: DynamicLangReg;
    zsh: DynamicLangReg;
    styl: DynamicLangReg;
    ts: DynamicLangReg;
    cmd: DynamicLangReg;
    vim: DynamicLangReg;
    vimscript: DynamicLangReg;
    vy: DynamicLangReg;
    文言: DynamicLangReg;
    yml: DynamicLangReg;
};
declare const bundledLanguages: {
    batch: DynamicLangReg;
    be: DynamicLangReg;
    cdc: DynamicLangReg;
    clj: DynamicLangReg;
    ql: DynamicLangReg;
    "c#": DynamicLangReg;
    cs: DynamicLangReg;
    cql: DynamicLangReg;
    dockerfile: DynamicLangReg;
    erl: DynamicLangReg;
    "f#": DynamicLangReg;
    fs: DynamicLangReg;
    gjs: DynamicLangReg;
    gts: DynamicLangReg;
    hbs: DynamicLangReg;
    hs: DynamicLangReg;
    properties: DynamicLangReg;
    js: DynamicLangReg;
    fsl: DynamicLangReg;
    kql: DynamicLangReg;
    makefile: DynamicLangReg;
    md: DynamicLangReg;
    nar: DynamicLangReg;
    nf: DynamicLangReg;
    objc: DynamicLangReg;
    ps: DynamicLangReg;
    ps1: DynamicLangReg;
    jade: DynamicLangReg;
    py: DynamicLangReg;
    perl6: DynamicLangReg;
    rb: DynamicLangReg;
    rs: DynamicLangReg;
    shader: DynamicLangReg;
    bash: DynamicLangReg;
    console: DynamicLangReg;
    sh: DynamicLangReg;
    shell: DynamicLangReg;
    zsh: DynamicLangReg;
    styl: DynamicLangReg;
    ts: DynamicLangReg;
    cmd: DynamicLangReg;
    vim: DynamicLangReg;
    vimscript: DynamicLangReg;
    vy: DynamicLangReg;
    文言: DynamicLangReg;
    yml: DynamicLangReg;
    abap: DynamicLangReg;
    "actionscript-3": DynamicLangReg;
    ada: DynamicLangReg;
    apache: DynamicLangReg;
    apex: DynamicLangReg;
    apl: DynamicLangReg;
    applescript: DynamicLangReg;
    ara: DynamicLangReg;
    asm: DynamicLangReg;
    astro: DynamicLangReg;
    awk: DynamicLangReg;
    ballerina: DynamicLangReg;
    bat: DynamicLangReg;
    beancount: DynamicLangReg;
    berry: DynamicLangReg;
    bibtex: DynamicLangReg;
    bicep: DynamicLangReg;
    blade: DynamicLangReg;
    c: DynamicLangReg;
    cadence: DynamicLangReg;
    clarity: DynamicLangReg;
    clojure: DynamicLangReg;
    cmake: DynamicLangReg;
    cobol: DynamicLangReg;
    codeql: DynamicLangReg;
    coffee: DynamicLangReg;
    cpp: DynamicLangReg;
    crystal: DynamicLangReg;
    csharp: DynamicLangReg;
    css: DynamicLangReg;
    cue: DynamicLangReg;
    cypher: DynamicLangReg;
    d: DynamicLangReg;
    dart: DynamicLangReg;
    dax: DynamicLangReg;
    diff: DynamicLangReg;
    docker: DynamicLangReg;
    "dream-maker": DynamicLangReg;
    elixir: DynamicLangReg;
    elm: DynamicLangReg;
    erb: DynamicLangReg;
    erlang: DynamicLangReg;
    fish: DynamicLangReg;
    fsharp: DynamicLangReg;
    gdresource: DynamicLangReg;
    gdscript: DynamicLangReg;
    gdshader: DynamicLangReg;
    gherkin: DynamicLangReg;
    "git-commit": DynamicLangReg;
    "git-rebase": DynamicLangReg;
    "glimmer-js": DynamicLangReg;
    "glimmer-ts": DynamicLangReg;
    glsl: DynamicLangReg;
    gnuplot: DynamicLangReg;
    go: DynamicLangReg;
    graphql: DynamicLangReg;
    groovy: DynamicLangReg;
    hack: DynamicLangReg;
    haml: DynamicLangReg;
    handlebars: DynamicLangReg;
    haskell: DynamicLangReg;
    hcl: DynamicLangReg;
    hjson: DynamicLangReg;
    hlsl: DynamicLangReg;
    html: DynamicLangReg;
    http: DynamicLangReg;
    imba: DynamicLangReg;
    ini: DynamicLangReg;
    java: DynamicLangReg;
    javascript: DynamicLangReg;
    "jinja-html": DynamicLangReg;
    jison: DynamicLangReg;
    json: DynamicLangReg;
    json5: DynamicLangReg;
    jsonc: DynamicLangReg;
    jsonl: DynamicLangReg;
    jsonnet: DynamicLangReg;
    jssm: DynamicLangReg;
    jsx: DynamicLangReg;
    julia: DynamicLangReg;
    kotlin: DynamicLangReg;
    kusto: DynamicLangReg;
    latex: DynamicLangReg;
    less: DynamicLangReg;
    liquid: DynamicLangReg;
    lisp: DynamicLangReg;
    logo: DynamicLangReg;
    lua: DynamicLangReg;
    make: DynamicLangReg;
    markdown: DynamicLangReg;
    marko: DynamicLangReg;
    matlab: DynamicLangReg;
    mdx: DynamicLangReg;
    mermaid: DynamicLangReg;
    narrat: DynamicLangReg;
    nextflow: DynamicLangReg;
    nginx: DynamicLangReg;
    nim: DynamicLangReg;
    nix: DynamicLangReg;
    "objective-c": DynamicLangReg;
    "objective-cpp": DynamicLangReg;
    ocaml: DynamicLangReg;
    pascal: DynamicLangReg;
    perl: DynamicLangReg;
    php: DynamicLangReg;
    plsql: DynamicLangReg;
    postcss: DynamicLangReg;
    powerquery: DynamicLangReg;
    powershell: DynamicLangReg;
    prisma: DynamicLangReg;
    prolog: DynamicLangReg;
    proto: DynamicLangReg;
    pug: DynamicLangReg;
    puppet: DynamicLangReg;
    purescript: DynamicLangReg;
    python: DynamicLangReg;
    r: DynamicLangReg;
    raku: DynamicLangReg;
    razor: DynamicLangReg;
    reg: DynamicLangReg;
    rel: DynamicLangReg;
    riscv: DynamicLangReg;
    rst: DynamicLangReg;
    ruby: DynamicLangReg;
    rust: DynamicLangReg;
    sas: DynamicLangReg;
    sass: DynamicLangReg;
    scala: DynamicLangReg;
    scheme: DynamicLangReg;
    scss: DynamicLangReg;
    shaderlab: DynamicLangReg;
    shellscript: DynamicLangReg;
    smalltalk: DynamicLangReg;
    solidity: DynamicLangReg;
    sparql: DynamicLangReg;
    sql: DynamicLangReg;
    "ssh-config": DynamicLangReg;
    stata: DynamicLangReg;
    stylus: DynamicLangReg;
    svelte: DynamicLangReg;
    swift: DynamicLangReg;
    "system-verilog": DynamicLangReg;
    tasl: DynamicLangReg;
    tcl: DynamicLangReg;
    tex: DynamicLangReg;
    toml: DynamicLangReg;
    tsx: DynamicLangReg;
    turtle: DynamicLangReg;
    twig: DynamicLangReg;
    typescript: DynamicLangReg;
    v: DynamicLangReg;
    vb: DynamicLangReg;
    verilog: DynamicLangReg;
    vhdl: DynamicLangReg;
    viml: DynamicLangReg;
    "vue-html": DynamicLangReg;
    vue: DynamicLangReg;
    vyper: DynamicLangReg;
    wasm: DynamicLangReg;
    wenyan: DynamicLangReg;
    wgsl: DynamicLangReg;
    wolfram: DynamicLangReg;
    xml: DynamicLangReg;
    xsl: DynamicLangReg;
    yaml: DynamicLangReg;
    zenscript: DynamicLangReg;
};

type DynamicThemeReg = () => Promise<{
    default: ThemeRegisterationRaw;
}>;
declare const bundledThemes: {
    "css-variables": DynamicThemeReg;
    "dark-plus": DynamicThemeReg;
    dracula: DynamicThemeReg;
    "dracula-soft": DynamicThemeReg;
    "github-dark": DynamicThemeReg;
    "github-dark-dimmed": DynamicThemeReg;
    "github-light": DynamicThemeReg;
    hc_light: DynamicThemeReg;
    "light-plus": DynamicThemeReg;
    "material-theme": DynamicThemeReg;
    "material-theme-darker": DynamicThemeReg;
    "material-theme-lighter": DynamicThemeReg;
    "material-theme-ocean": DynamicThemeReg;
    "material-theme-palenight": DynamicThemeReg;
    "min-dark": DynamicThemeReg;
    "min-light": DynamicThemeReg;
    monokai: DynamicThemeReg;
    nord: DynamicThemeReg;
    "one-dark-pro": DynamicThemeReg;
    poimandres: DynamicThemeReg;
    "rose-pine": DynamicThemeReg;
    "rose-pine-dawn": DynamicThemeReg;
    "rose-pine-moon": DynamicThemeReg;
    "slack-dark": DynamicThemeReg;
    "slack-ochin": DynamicThemeReg;
    "solarized-dark": DynamicThemeReg;
    "solarized-light": DynamicThemeReg;
    "vitesse-dark": DynamicThemeReg;
    "vitesse-light": DynamicThemeReg;
};

declare enum FontStyle {
    NotSet = -1,
    None = 0,
    Italic = 1,
    Bold = 2,
    Underline = 4
}

interface IThemedTokenScopeExplanation {
    scopeName: string;
    themeMatches: any[];
}
interface IThemedTokenExplanation {
    content: string;
    scopes: IThemedTokenScopeExplanation[];
}
/**
 * A single token with color, and optionally with explanation.
 *
 * For example:
 *
 * {
 *   "content": "shiki",
 *   "color": "#D8DEE9",
 *   "explanation": [
 *     {
 *       "content": "shiki",
 *       "scopes": [
 *         {
 *           "scopeName": "source.js",
 *           "themeMatches": []
 *         },
 *         {
 *           "scopeName": "meta.objectliteral.js",
 *           "themeMatches": []
 *         },
 *         {
 *           "scopeName": "meta.object.member.js",
 *           "themeMatches": []
 *         },
 *         {
 *           "scopeName": "meta.array.literal.js",
 *           "themeMatches": []
 *         },
 *         {
 *           "scopeName": "variable.other.object.js",
 *           "themeMatches": [
 *             {
 *               "name": "Variable",
 *               "scope": "variable.other",
 *               "settings": {
 *                 "foreground": "#D8DEE9"
 *               }
 *             },
 *             {
 *               "name": "[JavaScript] Variable Other Object",
 *               "scope": "source.js variable.other.object",
 *               "settings": {
 *                 "foreground": "#D8DEE9"
 *               }
 *             }
 *           ]
 *         }
 *       ]
 *     }
 *   ]
 * }
 *
 */
interface IThemedToken {
    /**
     * The content of the token
     */
    content: string;
    /**
     * 6 or 8 digit hex code representation of the token's color
     */
    color?: string;
    /**
     * Font style of token. Can be None/Italic/Bold/Underline
     */
    fontStyle?: FontStyle;
    /**
     * Explanation of
     *
     * - token text's matching scopes
     * - reason that token text is given a color (one matching scope matches a rule (scope -> color) in the theme)
     */
    explanation?: IThemedTokenExplanation[];
}

type BuiltinLanguages = keyof typeof bundledLanguages;
type BuiltinThemes = keyof typeof bundledThemes;
type Awaitable<T> = T | Promise<T>;
type MaybeGetter<T> = Awaitable<MaybeModule<T>> | (() => Awaitable<MaybeModule<T>>);
type MaybeModule<T> = T | {
    default: T;
};
type ThemeInput = MaybeGetter<ThemeRegisteration | ThemeRegisterationRaw>;
type LanguageInput = MaybeGetter<LanguageRegistration>;
interface Nothing {
}
/**
 * type StringLiteralUnion<'foo'> = 'foo' | string
 * This has auto completion whereas `'foo' | string` doesn't
 * Adapted from https://github.com/microsoft/TypeScript/issues/29729
 */
type StringLiteralUnion<T extends U, U = string> = T | (U & Nothing);
interface LanguageRegistration extends IRawGrammar {
    name: string;
    scopeName: string;
    displayName?: string;
    aliases?: string[];
    /**
     * A list of languages the current language embeds.
     * If manually specifying languages to load, make sure to load the embedded
     * languages for each parent language.
     */
    embeddedLangs?: string[];
    balancedBracketSelectors?: string[];
    unbalancedBracketSelectors?: string[];
}
interface CodeToHtmlOptions<Languages = string, Themes = string> {
    lang?: Languages;
    theme?: Themes;
    lineOptions?: LineOption[];
}
interface LineOption {
    /**
     * 1-based line number.
     */
    line: number;
    classes?: string[];
}
interface ThemeRegisterationRaw extends IRawTheme {
}
interface ThemeRegisteration extends ThemeRegisterationRaw {
    /**
     * @description theme name
     */
    name: string;
    /**
     * @description light/dark theme
     */
    type: 'light' | 'dark' | 'css';
    /**
     * @description tokenColors of the theme file
     */
    settings: any[];
    /**
     * @description text default foreground color
     */
    fg: string;
    /**
     * @description text default background color
     */
    bg: string;
    /**
     * @description relative path of included theme
     */
    include?: string;
    /**
     *
     * @description color map of the theme file
     */
    colors?: Record<string, string>;
}
interface HtmlRendererOptions {
    langId?: string;
    fg?: string;
    bg?: string;
    lineOptions?: LineOption[];
    elements?: ElementsOptions;
    themeName?: string;
}
interface ElementsOptions {
    pre?: (props: PreElementProps) => string;
    code?: (props: CodeElementProps) => string;
    line?: (props: LineElementProps) => string;
    token?: (props: TokenElementProps) => string;
}
interface ElementProps {
    children: string;
    [key: string]: unknown;
}
interface PreElementProps extends ElementProps {
    className: string;
    style: string;
}
interface CodeElementProps extends ElementProps {
}
interface LineElementProps extends ElementProps {
    className: string;
    lines: IThemedToken[][];
    line: IThemedToken[];
    index: number;
}
interface TokenElementProps extends ElementProps {
    style: string;
    tokens: IThemedToken[];
    token: IThemedToken;
    index: number;
}

export { Awaitable as A, BuiltinThemes as B, CodeToHtmlOptions as C, ElementsOptions as E, HtmlRendererOptions as H, LanguageInput as L, MaybeGetter as M, StringLiteralUnion as S, ThemeInput as T, BuiltinLanguages as a, bundledLanguages as b, bundledThemes as c, MaybeModule as d, LanguageRegistration as e, LineOption as f, ThemeRegisterationRaw as g, ThemeRegisteration as h, bundledLanguagesBase as i, bundledLanguagesAlias as j };
